@@ -1,11 +1,11 @@
 package Term::FormatColumns;
 {
-  $Term::FormatColumns::VERSION = '0.002';
+  $Term::FormatColumns::VERSION = '0.003';
 }
 
 use Sub::Exporter -setup => [
     exports => (
-        'format_columns', 'format_columns_for_fh'
+        'format_columns', 'format_columns_for_fh', 'format_columns_for_width',
     ),
 ];
 
@@ -15,7 +15,7 @@ use List::MoreUtils qw( part each_arrayref );
 use POSIX qw( ceil );
 
 sub format_columns(@) {
-    return format_columns_for_fh \*STDOUT, @_;
+    return format_columns_for_fh( \*STDOUT, @_ );
 }
 
 sub format_columns_for_fh($@) {
@@ -29,16 +29,21 @@ sub format_columns_for_fh($@) {
     # We're attached to a terminal, print column-wise alphabetically to fit the
     # terminal width
     my ( $term_width, undef, undef, undef ) = GetTerminalSize();
+    return format_columns_for_width( $term_width, @data );
+}
+
+sub format_columns_for_width($@) {
+    my ( $term_width, @data ) = @_;
     my $max_width = max map { length } @data;
     $max_width += 2; # make sure at least two spaces between data values
     my $columns = int( $term_width / $max_width );
     if ( $columns <= 1 ) {
         # Only one column, let the terminal handle things
-        return join "\n", @data;
+        return join "\n", @data, undef; # Add a \n to the end
     }
     my $output = '';
     my $column_width = int( $term_width / $columns );
-    my $format = "\%-${column_width}s" x $columns . "\n";
+    my $format = "\%-${column_width}s" x ($columns-1) . "\%s\n";
     my $rows = ceil( @data / $columns );
     my @index = part { int( $_ / $rows ) } 0..$#data;
     my $iter = each_arrayref @index;
@@ -80,9 +85,16 @@ Format the list of data. Returns a single string formatted and ready for output.
 
     my $string = format_columns_for_fh $fh, @array;
 
+=head2 format_columns_for_width
+
+    my $string = format_columns_for_width 78, @array;
+
+Format the given data for the given width. This allows you to use this module without
+being attached to a known/knowable terminal.
+
 =head1 COPYRIGHT
 
-Copyright 2012, Doug Bell <preaction@me.com>
+Copyright 2012, Doug Bell <preaction@cpan.org>
 
 =head1 LICENSE
 
